package xptoolkit.cactus;

import org.apache.cactus.*;
import javax.servlet.ServletException;
import java.io.IOException;
import junit.framework.*;

/**
 * $Revision: 1.3 $. Helder da Rocha (helder@ibpinet.net). $Date: 2002/02/24 20:36:58 $.
 * Modified version of example application from "Java Tools for Extreme Programming" by Hightower/Lesiecki.
 * Test case for exercising Cactus tests and simple Cactus WebResponse response. 
 */
public class MapperServletTest extends ServletTestCase {
    
    public MapperServletTest(String name) {
        super(name);
    }
    public static TestSuite suite() {
        return new TestSuite(MapperServletTest.class);
    }
    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    private MapperServlet servlet;
    
    /** This is the client-side set-up for the testDoGet() method.
        The clientSideRequest variable will be copied into the server-side
        request variable
        
        Do not define instance variables in here. They are only used by part
        of the application which runs on the client.
      */
    public void beginDoGet(WebRequest clientSideRequest) {
        clientSideRequest.addParameter("user", "Jabberwock");
    }
    
    /** This is the server-side set-up for all methods */
    public void setUp() throws ServletException {
        this.config.setInitParameter("ALL_CAPS", "true"); // sets servlet init param
        servlet = new MapperServlet();
        servlet.init(this.config); // call servlet initialization - MANDATORY!
    }
    
    /** Executed on the server side */
    public void testDoGet() throws IOException {
        servlet.doGet(this.request, this.response);
        
        String value = (String) session.getAttribute("user");
        assertEquals("Request parameter not mapped into session as expected",
                     "Jabberwock", value);
    }
    
    /** Executed on the server side */
    public void testUseAllCaps() {
        assertTrue("Servlet set to use all caps", servlet.useAllCaps());
    }
    
    /** This is the server-side finalization for all methods */
    public void tearDown() {
        System.out.println("TearDown() was called.");
    }
    
    /** 
      * This runs on the client side!
      * WebResponse is a string which contains a string with the data returned by the server.
      * There are two different types of WebResponse objects. HttpUnit's WebResponse
      * offers DOM and methods for dealing with HTML objects. This version tests the
      * returned string, including HTML.
      * The servlet which runs is not the MapperServlet but a mock servlet: ServletRedirector
      * (see lib/test-web.xml) so there are 3 additional parameters defined. That means we
      * can't assert the existence of only one parameter (although that will be the case
      * when the real application - MapperServlet - runs.)
      */
    public void endDoGet(WebResponse clientSideResponse) {
        String responseString = clientSideResponse.getText();
        // This is the full response string - note the extra parameters.
        System.out.println("Response string:\n" + responseString);
        
        // check that one of the parameters is the one we defined
        boolean paramInResponse = responseString.indexOf("USER</b></td><td>JABBERWOCK") > -1;
        assertTrue("Parameter not found in response as expected", paramInResponse);
    }

}
