package xptoolkit.cactus;

import org.apache.cactus.*;
import com.meterware.httpunit.WebTable;
import javax.servlet.ServletException;
import java.io.IOException;
import junit.framework.*;

/**
 * $Revision: 1.3 $. Helder da Rocha (helder@ibpinet.net). $Date: 2002/02/24 20:36:58 $.
 * Modified version of example application from "Java Tools for Extreme Programming" by Hightower/Lesiecki.
 * Test case for exercising Cactus tests and HttpUnit's WebResponse response. 
 */
public class MapperServletTest2 extends ServletTestCase {
    
    public MapperServletTest2(String name) {
        super(name);
    }
    public static TestSuite suite() {
        return new TestSuite(MapperServletTest2.class);
    }
    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    private MapperServlet servlet;
        
    /** This is the client-side set-up for the testDoGet() method.
        The clientSideRequest variable will be copied into the server-side
        request variable
        
        Do not define instance variables in here. They are only used by part
        of the application which runs on the client.
      */
    public void beginDoGet(WebRequest clientSideRequest) {
        clientSideRequest.addParameter("user", "Jabberwock");
    }
    
        /** This is the server-side set-up for all methods */
    public void setUp() throws ServletException {
        this.config.setInitParameter("ALL_CAPS", "true"); // sets servlet init param
        servlet = new MapperServlet();
        servlet.init(this.config); // call servlet initialization - MANDATORY!
    }
    
    /** Executed on the server side */
    public void testDoGet() throws IOException {
        servlet.doGet(this.request, this.response);
        
        String value = (String) session.getAttribute("user");
        assertEquals("Request parameter not mapped into session as expected",
                     "Jabberwock", value);
    }
    
    /** Executed on the server side */
    public void testUseAllCaps() {
        assertTrue("Servlet set to use all caps", servlet.useAllCaps());
    }
    
    /** This is the server-side finalization for all methods */
    public void tearDown() {
        System.out.println("TearDown() was called.");
    }
    
    /** 
      * This runs on the client side!
      * WebResponse is a string which contains a string with the data returned by the server.
      * There are two different types of WebResponse objects. HttpUnit's WebResponse
      * offers DOM and methods for dealing with HTML objects. This version tests the
      * returned string, including HTML.
      * The servlet which runs is not the MapperServlet but a mock servlet: ServletRedirector
      * (see lib/test-web.xml) so there are 3 additional parameters defined. That means we
      * can't assert the existence of only one parameter (although that will be the case
      * when the real application - MapperServlet - runs.)
      */
    public void endDoGet(com.meterware.httpunit.WebResponse clientSideResponse) throws org.xml.sax.SAXException {
        WebTable[] tables = clientSideResponse.getTables();
        assertNotNull(tables);
        assertEquals(tables.length, 1); // only one table should exist
        
        WebTable table = tables[0]; // first and only table
        int rows = table.getRowCount(); // we can't assume there is only one row in this case (see comments above)
        boolean keyDefined = false;
        
        // check in each table row and find the parameter we defined
        for (int i = 0; i < rows; i++) {
            String key   = table.getCellAsText(i, 0);
            String value = table.getCellAsText(i, 1);
            if (key.equals("USER")) {
                keyDefined = true;
                assertEquals("JABBERWOCK", value);
            }
        }
        
        if (!keyDefined) {
            fail("No key named USER was found!");
        }
    }

}
