package argonavis.pdf;

import java.io.*;
import org.apache.tools.ant.*;
import junit.framework.*;

/**
 * This Ant task uses Apache FOP 0.20 (xml.apache.org) to
 * transform XSL-FO documents into PDF documents
 */
public class FopTaskTest extends TestCase {
    
    private File sourceDir, destDir, foFile, pdfFile, inFile, outFile;
    private FopTask task;
    
    public FopTaskTest(java.lang.String testName) {
        super(testName);
    }
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    public static Test suite() {
        TestSuite suite = new TestSuite(FopTaskTest.class);
        return suite;
    }
    
    public void setUp() {
        task = new FopTask();
        
        sourceDir = new File("srcdirTest");
        foFile = new File("srcdirTest/test.fo");
        inFile = foFile;
        assertTrue("Required test directory does not exist!", sourceDir.exists());
        assertTrue("Required test file does not exist!", foFile.exists());
        
        destDir = new File("pdfdirTest");
        destDir.mkdir();
        
        pdfFile = new File("pdfdirTest/test.pdf");
        outFile = pdfFile;
    }
    
    public void tearDown() {
        pdfFile.delete();
        destDir.delete();
    }
    
    public void testExecute() throws BuildException {
        task.setDestdir(destDir);
        task.setBasedir(sourceDir);
        task.execute();
        assertTrue(pdfFile.exists());
        
        tearDown();
        
        task.setIn(inFile);
        task.setOut(outFile);
        task.execute();
        assertTrue(pdfFile.exists());
    }
    
    public void testSetOut() throws BuildException {
        task.setOut(outFile);
        assertEquals(task.getOut(), outFile);
    }
    
    public void testSetIn() throws BuildException {
        task.setIn(inFile);
        assertEquals(task.getIn(), inFile);
    }
    
    public void testSetBasedir() throws BuildException {
        task.setBasedir(sourceDir);
        assertEquals(task.getBasedir(), sourceDir);
    }
    
    public void testSetDestdir() throws BuildException {
        task.setDestdir(destDir);
        assertEquals(task.getDestdir(), destDir);
    }
    
    public void testGeneratePDF() throws IOException {
        FopTask.generatePDF(foFile, pdfFile);
        assertTrue(pdfFile.exists());
	}
    
}
