package junitdemo;

/**
 * Tiracentos.java
 * Last update on $Date 2000-09-19 16:48:13 GMT-03$
 * $Revision 1.14$
 * Classe utilitria que possui um mtodo rpido para remover acentos.
 * @author Henrique Leme - Editora Grficos Burti (hleme@macbbs.com.br)
 * @author Helder da Rocha (hlsr@uol.com.br)
 * @version 1.0
 */
public class Tiracentos {
    /** 
     * Tabela de substituio. A parte reference ao ASCII no foi alterada.
     * A parte estendida foi alterada a partir do caractere 0xA0. 
     * Os smbolos foram substitudos pelo caractere ASCII mais parecido.
     * As fraes 1/2 1/4 e 3/4 foram substitudas pelos nmeros 1, 2 e 3.
     */
	private static char[] semAcentos = {
        ///////// Parte ASCII - 00 a 7F ///////////////
        //////// Caracteres abaixo nao mudam //////////
		0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
		0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F,
		0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
		0x18, 0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F,
		0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
		0x28, 0x29, 0x2A, 0x2B, 0x2C, 0x2D, 0x2E, 0x2F,
		0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37,
		0x38, 0x39, 0x3A, 0x3B, 0x3C, 0x3D, 0x3E, 0x3F,
		0x40, 'A',  'B',  'C',  'D',  'E',  'F',  'G',
		'H',  'I',  'J',  'K',  'L',  'M',  'N',  'O',
		'P',  'Q',  'R',  'S',  'T',  'U',  'V',  'W',
		'X',  'Y',  'Z',  0x5B, 0x5C, 0x5D, 0x5E, 0x5F, 
		0x60, 'a',  'b',  'c',  'd',  'e',  'f',  'g',
		'h',  'i',  'j',  'k',  'l',  'm',  'n',  'o',
		'p',  'q',  'r',  's',  't',  'u',  'v',  'w',
		'x',  'y',  'z',  0x7B, 0x7C, 0x7D, 0x7E, 0x7F,
        ///////// Parte estendida 80 a FF /////////////
        /////// Caracteres de controle (mantidos) /////
		0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87,
	    0x88, 0x89, 0x8A, 0x8B, 0x8C, 0x8D, 0x8E, 0x8F,
	    0x90, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97,
		0x98, 0x99, 0x9A, 0x9B, 0x9C, 0x9D, 0x9E, 0x9F,
        // Simbolos (trocados por caractere parecido) //
		' ',  '!',  'c',  'L',  'o',  'Y',  '|',  'S',
		':',  'C',  'a',  '<',  '-',  '-',  'R',  '-',
		'o',  '~',  '2',  '3',  '\'', 'u',  'P',  '.',
		',',  '1',  'o',  '>',  '1',  '2',  '3',  '?',
        ///////// Letras sem acentos //////////////////
		'A',  'A',  'A',  'A',  'A',  'A',  'E',  'C',
		'E',  'E',  'E',  'E',  'I',  'I',  'I',  'I',
		'D',  'N',  'O',  'O',  'O',  'O',  'O',  'x',
		'O',  'U',  'U',  'U',  'U',  'Y',  'P',  'B',
		'a',  'a',  'a',  'a',  'a',  'a',  'e',  'c',
		'e',  'e',  'e',  'e',  'i',  'i',  'i',  'i',
		'd',  'n',  'o',  'o',  'o',  'o',  'o',  '/',
		'o',  'u',  'u',  'u',  'u',  'y',  'p',  'y'
	};

    /**
     * Recebe uma string ISO-8859-1 como parmetro e devolve uma
     * string sem acentos. Este mtodo no verifica se a string
     * recebida realmente  ISO-8859-1. Este mtodo foi construdo
     * para converter texto. Caracteres de controle no sero alterados
     * e smbolos sero convertidos em caracteres parecidos.
     * @param origem texto original (pode ter acentos)
     * @return texto com os acentos removidos.
     */
	public static String toAscii (String origem) {
        int len = origem.length();
		StringBuffer destino = new StringBuffer(len);
		// percorre todos os caracteres da string origem 
		for (int i = 0; i < len; i++) {
			// converte o caractere acentuado segundo a tabela semAcentos 
			char c = semAcentos[origem.charAt(i)];
			destino = destino.append(semAcentos[origem.charAt(i)]);
		}
		return destino.toString();
	}
}


