package taglibdemo;

import javax.servlet.jsp.tagext.*;
import javax.servlet.jsp.*;
import java.lang.reflect.*;
import java.beans.*;
import java.io.IOException;

public class ForPropertyTag extends BodyTagSupport {
    private String name, property, id;
    private Class elementClass;
    
    private Object bean;
    private Method elementMethod;
    private int size, index;
    
    public void setId(String id) {
        this.id = id;
    }
    public void setProperty(String property) {
        this.property = property;
    }
    public void setName(String name) {
        this.name = name;
    }
    public void setElementClass(Class elementClass) {
        this.elementClass = elementClass;
    }
    
    public String getId() {
        return id;
    }
    public String getProperty() {
        return property;
    }
    public String getName() {
        return name;
    }
    public Class getElementClass() {
        return elementClass;
    }
    
    public void setClassName(String className) throws ClassNotFoundException {
        setElementClass(Class.forName(className));
    }
    
    public String getClassName() {
        return getElementClass().getName();
    }
    
    public int doStartTag() throws JspException {
        bean = pageContext.getAttribute(name);
        if (bean != null) {
            Class beanClass = bean.getClass();
            this.initSize(beanClass);
            if (size > 0) {
                this.initElementMethod(beanClass);
                index = 0;
                this.assignElement();
                return EVAL_BODY_AGAIN;
            } else {
                return SKIP_BODY;
            }
        } else {
            throw new JspTagException("No bean '" + name + "' available for &lt;forProperty&gt; tag.");
        }
    }
    
    public int doAfterBody() throws JspException {
        BodyContent body = getBodyContent();
        try {
            body.writeOut(getPreviousOut());
        } catch (IOException e) {
            throw new JspTagException("Unexpected I/I Error: " + e);
        }
        body.clearBody();
        
        if (++index < size) {
            assignElement();
            return EVAL_BODY_AGAIN;
        } else {
            return SKIP_BODY;
        }
    }
    
    public void release() {
        super.release();
        name = null;
        property = null;
        id = null;
        elementClass = null;
        bean = null;
        index = 0;
        size = 0;
        elementMethod = null;
    }
    
    void assignElement() throws JspException {
        Object element = invokeMethod(elementMethod, index, "element");
        pageContext.setAttribute(id, element);
    }
    
    void initSize(Class beanClass) throws JspException {
        Method method = getReader(beanClass, property + "Size", int.class); // propSize is a convention
        Object sizeWrapper = this.invokeMethod(method, "size");
        size = ((Integer) sizeWrapper).intValue();
    }
    
    void initElementMethod(Class beanClass) throws JspException {
        elementMethod = this.getIndexedReader(beanClass, property, elementClass);
    }
    
    Method getReader(Class beanClass, String property, Class returnType) throws JspException {
        try {
            BeanInfo beanInfo = Introspector.getBeanInfo(beanClass);
            PropertyDescriptor[] descriptors = beanInfo.getPropertyDescriptors();
            for (int i = 0; i < descriptors.length; i++) {
                if (descriptors[i].getName().equals(property) && descriptors[i].getPropertyType() == returnType) {
                    return descriptors[i].getReadMethod();
                }
            }
            throw new JspTagException("Bean '" + name + "' has no boolean property named '" 
                                      + property + "' of type " + returnType.getName() +
                                      " for the <forProperty> tag.");
            
        } catch (IntrospectionException e) {
            throw new JspTagException("" + e);
        }
    }
    
    Method getIndexedReader(Class beanClass, String property, Class returnType) throws JspException {
        try {
            BeanInfo beanInfo = Introspector.getBeanInfo(beanClass);
            PropertyDescriptor[] descriptors = beanInfo.getPropertyDescriptors();
            for (int i = 0; i < descriptors.length; i++) {
                if (descriptors[i] instanceof IndexedPropertyDescriptor && descriptors[i].getName().equals(property)) {
                    IndexedPropertyDescriptor ipd = (IndexedPropertyDescriptor) descriptors[i];
                    if (ipd.getIndexedPropertyType() == returnType) {
                        return ipd.getIndexedReadMethod();
                    }
                }
            }
            throw new JspTagException("Bean '" + name + "' has no boolean property named '" 
                                      + property + "' of type " + returnType.getName() +
                                      " for the <forProperty> tag.");
            
        } catch (IntrospectionException e) {
            throw new JspTagException("" + e);
        }
    }
    
    Object invokeMethod(Method method, String label) throws JspException {
        return invokeMethod(method, new Object[0], label);
    }
    
    Object invokeMethod(Method method, int arg, String label) throws JspException {
        Integer[] args = { new Integer(arg) };
        return invokeMethod (method, args, label);
    }

    Object invokeMethod(Method method, Object[] args, String label) throws JspException {
        try {
            return method.invoke(bean, args);
        } catch (InvocationTargetException e) {
            throw new JspTagException("Unable to invoke " + label + " method corresponding to property '" 
                                             + property + "' of bean '" + name + "' for <forProperty> tag.");
        } catch (IllegalAccessException e) {
            throw new JspTagException("Unable to invoke " + label + " method corresponding to property '" 
                                             + property + "' of bean '" + name + "' for <forProperty> tag.");
        }
    }

}
