package taglibdemo;

import javax.servlet.jsp.tagext.TagSupport;
import javax.servlet.jsp.*;
import java.lang.reflect.*;
import java.beans.*;

public class IfPropertyTag extends TagSupport {
    private String name, property;
    private String action = "include";
    
    public void setAction(String action) {
        this.action = action;
    }
    public void setProperty(String property) {
        this.property = property;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    public String getAction() {
        return action;
    }
    public String getProperty() {
        return property;
    }
    public String getName() {
        return name;
    }
    
    boolean evalPropertyValue() throws IntrospectionException {
        Object bean = pageContext.getAttribute(name); // get bean by name
        if (bean != null) {
            Method readerMethod = getPropertyReader(bean); // get the method that reads properties
            return readProperty(bean, readerMethod);  // call the method and return the property value (true or false)
        }
        throw new IntrospectionException("Bean '" + name + "' not found for <ifProperty> tag.");
    }
    
    boolean readProperty(Object bean, Method reader) throws IntrospectionException {
        try {
            Object result = reader.invoke(bean, null); // the instance where the method should be invoked, array of args
            return ( (Boolean)result ).booleanValue();
        } catch (InvocationTargetException e) {
            throw new IntrospectionException("Unable to access property '" + property + "' of bean '" + name + "' for <ifProperty> tag.");
        } catch (IllegalAccessException e) {
            throw new IntrospectionException("Unable to access property '" + property + "' of bean '" + name + "' for <ifProperty> tag.");
        }
    }
    
    Method getPropertyReader(Object bean) throws IntrospectionException {
        Class beanClass = bean.getClass();
        BeanInfo beanInfo = Introspector.getBeanInfo(beanClass);
        PropertyDescriptor[] descriptors = beanInfo.getPropertyDescriptors();
        for (int i = 0; i < descriptors.length; i++) {
            if ( descriptors[i].getName().equals(property) && descriptors[i].getPropertyType() == boolean.class) {
                return descriptors[i].getReadMethod();
            }
        }
        throw new IntrospectionException("Bean '" + name + "' has no boolean property named '" 
                                                  + property + "' for the <ifProperty> tag.");
    }
    
    public int doStartTag() throws JspException {
        try {
            boolean propertyValue = evalPropertyValue();
            boolean exclude = action.equalsIgnoreCase("exclude");
            
            if (exclude) {
                propertyValue = !propertyValue;
            }
            
            return propertyValue ? EVAL_BODY_INCLUDE : SKIP_BODY;
            
        } catch (IntrospectionException e) {
            throw new JspTagException("" + e);
        }
    }
    
    public void release() {
        super.release();
        name = null;
        property = null;
        action = "include";
    }
}
