package taskdemo;

import java.io.*;
import org.apache.tools.ant.*;

/**
 * Example Ant task that receives a string 
 * and prints it out in upper case or in
 * lower case.
 *
 * Try extending the Echo task for a more
 * efficient result.
 */
public class ChangeCaseTask extends Task {
    
    public static final int UPPERCASE = 1;
    public static final int LOWERCASE = -1;
    
    private String message;
    private int strCase = 0;
    
    /**
     * This runs the task. The log() method was inherited. It will print
     * a message to an output stream. The standard output is default.
     */
    public void execute() throws BuildException {
        if (message == null) {
            throw new BuildException("The 'message' attribute is required for the <changecase> task.");
        }
        log(getMessage());
    }
    
    /**
     * Every public setXXX() method defines an attribute.
     * This one defines the required 'message' attribute.
     */
    public void setMessage(String message) throws BuildException {
        this.message = message;
    }
    
    /**
     * Every public setXXX() method defines an attribute.
     * This one defines the optional 'case' attribute.
     */
    public void setCase(String strCase) throws BuildException {
        if (strCase.toLowerCase().equals("uppercase")) {
            this.strCase = UPPERCASE;
        } else if (strCase.toLowerCase().equals("lowercase")) {
            this.strCase = LOWERCASE;
        } else {
            throw new BuildException("Valid options for 'case' attribute are 'lowercase' and 'uppercase'.");
        }
    }
    
    /**
     * Modifies current message for printing according to selected case
     */
    public String getMessage() {
        switch(strCase) {
            case 1:
                return message.toUpperCase();
            case -1:
                return message.toLowerCase();
            default:
                return message;
        }
    }
    
}
